/*
 * COPYRIGHT (c) 2009 by Institute of Computer Science, 
 * Foundation for Research and Technology - Hellas
 * Contact: 
 *      POBox 1385, Heraklio Crete, GR-700 13 GREECE
 *      Tel:+30-2810-391632
 *      Fax: +30-2810-391638
 *      E-mail: isl@ics.forth.gr
 *      http://www.ics.forth.gr/isl/cci.html
 *
 *  Original Author  :  K.V. Chandrinos
 *  Modified by: Georgis Christos
 *
 *  This file is part of  ISL - Time-Primitive JAVA-API
 *
 *  ISL - Time-Primitive JAVA-API is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  ISL - Time-Primitive JAVA-API is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with ISL - Time-Primitive JAVA-API.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 package sistime;
//A class for conversion between different Greek scripts
//by K.V. Chandrinos with the (usual) excellent insight of 
//John Immerkaer - January 22, 1998

public class GreekConverter {

//some lookup tables...

/*final static int[]Wint={128, 129, 130, 131, 132, 133, 134, 135, 
                         136, 137, 138, 139, 140, 141, 142, 143, 
                         144, 145, 146, 147, 148, 149, 150, 151,
                         152, 153, 154, 155, 156, 157, 158, 159,
                         160, 161, 162, 163, 164, 165, 166, 167,
                         168, 169, 170, 171, 172, 173, 174, 175, 
                         176, 177, 178, 179, 180, 181, 182, 183, 
                         184, 185, 186, 187, 188, 189, 190, 191, 
                         192, 193, 194, 195, 196, 197, 198, 199, 
                         200, 201, 202, 203, 204, 205, 206, 207, 
                         208, 209, 210, 211, 212, 213, 214, 215,
                         216, 217, 218, 219, 220, 221, 222, 223,
                         224, 225, 226, 227, 228, 229, 230, 231, 
                         232, 233, 234, 235, 236, 237, 238, 239,
                         240, 241, 242, 243, 244, 245, 246, 247,
                         248, 249, 250, 251, 252, 253, 254, 255}; */

final static int[] Dint={128, 129, 130, 131, 132, 133, 134, 135, 
                         136, 137, 138, 139, 140, 141, 142, 143, 
                         144, 145, 146, 147, 148, 149, 150, 151,
                         152, 153, 154, 155, 156, 157, 158, 159,
                         160, 161, 128, 163, 164, 165, 166, 167,
                         168, 169, 170, 171, 172, 173, 174, 175, 
                         176, 177, 178, 179, 180, 181, 182, 183, 
                         132, 134, 136, 187, 142, 189, 147, 151, 
                         228, 128, 129, 130, 131, 132, 133, 134, 
                         135, 136, 137, 138, 139, 140, 141, 142, 
                         143, 144, 210, 145, 146, 147, 148, 149,
                         150, 151, 136, 147, 225, 226, 227, 229,
                         232, 152, 153, 154, 155, 156, 157, 158, 
                         159, 160, 161, 162, 163, 164, 165, 166,
                         167, 168, 170, 169, 171, 172, 173, 174,
                         175, 224, 228, 232, 230, 231, 233, 219};

final static int[] Wint={193, 194, 195, 196, 197, 198, 199, 200, 
                         201, 202, 203, 204, 205, 206, 207, 208, 
                         209, 211, 212, 213, 214, 215, 216, 217,
                         225, 226, 227, 228, 229, 230, 231, 232,  
                         233, 234, 235, 236, 237, 238, 239, 240,
                         241, 243, 242, 244, 245, 246, 247, 248, 
                         176, 177, 178, 179, 180, 181, 182, 183, 
                         184, 185, 186, 187, 188, 189, 190, 191, 
                         192, 193, 194, 195, 196, 197, 198, 199, 
                         200, 201, 202, 203, 204, 205, 206, 207, 
                         208, 209, 210, 211, 212, 213, 214, 215,
                         216, 217, 218, 219, 220, 221, 222, 223,
                         249, 220, 221, 222, 250, 223, 252, 253, 
                         251, 254, 162, 184, 185, 186, 188, 190,
                         191, 241, 242, 243, 244, 245, 246, 247,
                         248, 249, 250, 251, 252, 253, 254, 255};

 final static int[] W2Uint={128, 129, 130, 131, 132, 133, 134, 135, 
                            136, 137, 138, 139, 140, 141, 142, 143, 
                            144, 145, 146, 147, 148, 149, 150, 151,
                            152, 153, 154, 155, 156, 157, 158, 159,
                            160, 0x385, 0x386, 163, 164, 165, 166, 167,
                            168, 169, 170, 171, 172, 173, 174, 175, 
                            176, 177, 178, 179, 0x374, 181,  182, 183, 
                            0x388, 0x389, 0x38a,   187, 0x38c,   189, 0x38e, 0x38f, 
                            0x390, 0x391, 0x392, 0x393, 0x394, 0x395, 0x396, 0x397, 
                            0x398, 0x399, 0x39a, 0x39b, 0x39c, 0x39d, 0x39e, 0x39f, 
                            0x3a0, 0x3a1,   210, 0x3a3, 0x3a4, 0x3a5, 0x3a6, 0x3a7,
                            0x3a8, 0x3a9, 0x3aa, 0x3ab, 0x3ac, 0x3ad, 0x3ae, 0x3af,
                            0x3b0, 0x3b1, 0x3b2, 0x3b3, 0x3b4, 0x3b5, 0x3b6, 0x3b7, 
                            0x3b8, 0x3b9, 0x3ba, 0x3bb, 0x3bc, 0x3bd, 0x3be, 0x3bf,
                            0x3c0, 0x3c1, 0x3c2, 0x3c3, 0x3c4, 0x3c5, 0x3c6, 0x3c7,
                            0x3c8, 0x3c9, 0x3ca, 0x3cb, 0x3cc, 0x3cd, 0x3ce,   255}; 
                            
 final static int[] U2Wint={0x370, 0x371, 0x372, 0x373,   180,   130, 0x376, 0x377,
                            0x378, 0x379, 0x37a, 0x37b, 0x37c, 0x37d,    59, 0x37f,
                            0x380, 0x381, 0x382, 0x383,    39,   161,   162,   183,
                              184,   185,   186, 0x38b,   188, 0x38d,   190,   191,
                              192,   193,   194,   195,   196,   197,   198,   199, 
                              200,   201,   202,   203,   204,   205,   206,   207, 
                              208,   209, 0x3a2,   211,   212,   213,   214,   215,
                              216,   217,   218,   219,   220,   221,   222,   223,
                              249,   220,   221,   222,   250,   223,   252,   253, 
                              251,   254,   234,   235,   236,   237,   238,   239,
                              240,   241,   242,   243,   244,   245,   246,   247,
                              248,   249,   250,   251,   252,   253,   254, 0x3cf};
  
  final static int[] ISO72Uint={ 0xB0,  0xB1,  0xB2,  0xB3, 0x384,
                                0x385, 0x386,  0xB7, 0x388, 0x389, 0x38A, 0xBB,  0x38C,
                                 0xBD, 0x38E, 0x38F, 0x390, 0x391, 0x392, 0x393, 0x394,
                                0x395, 0x396, 0x397, 0x398, 0x399, 0x39A, 0x39B, 0x39C,
                                0x39D, 0x39E, 0x39F, 0x3A0, 0x3A1, 0x3a2, 0x3A3, 0x3A4, 0x3A5,
                                0x3A6, 0x3A7, 0x3A8, 0x3A9, 0x3AA, 0x3AB, 0x3AC, 0x3AD,
                                0x3AE, 0x3AF, 0x3B0, 0x3B1, 0x3B2, 0x3B3, 0x3B4, 0x3B5,
                                0x3B6, 0x3B7, 0x3B8, 0x3B9, 0x3BA, 0x3BB, 0x3BC, 0x3BD,
                                0x3BE, 0x3BF, 0x3C0, 0x3C1, 0x3C2, 0x3C3, 0x3C4, 0x3C5,
                                0x3C6, 0x3C7, 0x3C8, 0x3C9, 0x3CA, 0x3CB, 0x3CC, 0x3CD,
                                0x3CE, 0xFF}; 

  final static int[] ISO72UintNS={ 0xB0,  0xB1,  0xB2,  0xB3, 0x384,
                                0x385, 0x386,  0xB7, 0x388, 0x389, 0x38A, 0xBB,  0x38C,
                                 0xBD, 0x38E, 0x38F, 0x390, 0x391, 0x392, 0x393, 0x394,
                                0x395, 0x396, 0x397, 0x398, 0x399, 0x39A, 0x39B, 0x39C,
                                0x39D, 0x39E, 0x39F, 0x3A0, 0x3A1, 0x3a2, 0x3A3, 0x3A4, 0x3A5,
                                0x3A6, 0x3A7, 0x3A8, 0x3A9, 0x3AA, 0x3AB, 0x3b1, 0x3b5,
                                0x3b7, 0x3b9, 0x3B0, 0x3B1, 0x3B2, 0x3B3, 0x3B4, 0x3B5,
                                0x3B6, 0x3B7, 0x3B8, 0x3B9, 0x3BA, 0x3BB, 0x3BC, 0x3BD,
                                0x3BE, 0x3BF, 0x3C0, 0x3C1, 0x3C2, 0x3C3, 0x3C4, 0x3C5,
                                0x3C6, 0x3C7, 0x3C8, 0x3C9, 0x3CA, 0x3CB, 0x3bf, 0x3c5,
                                0x3c9, 0xFF}; 

 final static int[] Uni2Uni_intNS={
                                0x370, 0x371, 0x372, 0x373, 0x374, 0x375, 0x376, 0x377,
                                0x378, 0x379, 0x37A, 0x37B, 0x37C, 0x37D, 0x37E, 0x37F,
                                0x380, 0x381, 0x382, 0x383, 0x384, 0x385, 0x391, 0x387,
                                0x395, 0x397, 0x399, 0x38B, 0x39f, 0x38D, 0x3a5, 0x3a9,
                                0x3b9, 0x391, 0x392, 0x393, 0x394, 0x395, 0x396, 0x397,
                                0x398, 0x399, 0x39A, 0x39B, 0x39C, 0x39D, 0x39E, 0x39F,
                                0x3A0, 0x3A1, 0x3A2, 0x3A3, 0x3A4, 0x3A5, 0x3A6, 0x3A7,
                                0x3A8, 0x3A9, 0x399, 0x3A5, 0x3b1, 0x3b5, 0x3b7, 0x3b9,
                                0x3c5, 0x3B1, 0x3B2, 0x3B3, 0x3B4, 0x3B5, 0x3B6, 0x3B7,
                                0x3B8, 0x3B9, 0x3BA, 0x3BB, 0x3BC, 0x3BD, 0x3BE, 0x3BF,
                                0x3C0, 0x3C1, 0x3C2, 0x3C3, 0x3C4, 0x3C5, 0x3C6, 0x3C7,
                                0x3C8, 0x3C9, 0x3b9, 0x3c5, 0x3bf, 0x3c5, 0x3c9, 0x3CF};
                                
  final static int[] U2ISO7int={0xB0, 0xB1, 0xB2, 0xB3, 0xB4,
                                0xB5, 0xB6, 0xB7, 0xB8, 0xB9, 0xBA, 0xBB, 0xBC,
                                0xBD, 0xBE, 0xBF, 0xC0, 0xC1, 0xC2, 0xC3, 0xC4,
                                0xC5, 0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xCB, 0xCC,
                                0xCD, 0xCE, 0xCF, 0xD0, 0xD1, 0xD2, 0xD3, 0xD4, 0xD5,
                                0xD6, 0xD7, 0xD8, 0xD9, 0xDA, 0xDB, 0xDC, 0xDD,
                                0xDE, 0xDF, 0xE0, 0xE1, 0xE2, 0xE3, 0xE4, 0xE5,
                                0xE6, 0xE7, 0xE8, 0xE9, 0xEA, 0xEB, 0xEC, 0xED,
                                0xEE, 0xEF, 0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5,
                                0xF6, 0xF7, 0xF8, 0xF9, 0xFA, 0xFB, 0xFC, 0xFD,
                                0xFE, 0xFF}; 
  
  
  static char[] D = new char[256-128];
  static char[] W = new char[256-128];
  static char[] W2U = new char[256-128];
  static char[] U2W = new char[0x3d0 - 0x370];
  static char[] ISO72U = new char[0x100 - 0xb0];
  static char[] ISO72UNS = new char[0x100 - 0xb0];
  static char[] Uni2UniNS = new char[0x3d0 - 0x370];
  static char[] U2ISO7 = new char[0x3d0 - 0x380];
  
  
  
  //static initializer...

  static {
    for (int i=128; i<=255; i++) {
      D[i-128]= (char) Dint[i-128];
      W[i-128]= (char) Wint[i-128];
      W2U[i-128]= (char) W2Uint[i-128];
    }
    for (int i=0x370; i<0x3d0; i++) {
      U2W[i-0x370]= (char) U2Wint[i-0x370];
    }
    for (int i=0xb0; i<0x100; i++) {
      ISO72U[i-0xb0]= (char) ISO72Uint[i-0xb0];
    }
    for (int i=0xb0; i<0x100; i++) {
      ISO72UNS[i-0xb0]= (char) ISO72UintNS[i-0xb0];
    }

    for (int i=0x370; i<0x3d0; i++) {
      Uni2UniNS[i-0x370]= (char) Uni2Uni_intNS[i-0x370];
    }

    for (int i=0x380; i<0x3d0; i++) {
      U2ISO7[i-0x380]= (char) U2ISO7int[i-0x380];
    }
  }

  //public char conversion methods

  public static char WinGk2DosGk(char c){
    if ( (c>=128) && (c<=255) ){
      c=D[((int)c)-128];
      }
    return c;  
  }
  public static char DosGk2WinGk(char c){
    if ( (c>=128) && (c<=255) ){
      c=W[((int)c)-128];
      }
    return c;  
  }

  public static char WinGk2Uni(char c){
    if ( (c>=128) && (c<=255) ){
      c=W2U[((int)c)-128];
      }
    return c;  
  }

  public static char Uni2WinGk(char c){
    if ( (c>=0x370) && (c<0x3d0) ){
      c=U2W[((int)c)-0x370];
      }
    return c;  
  }

  public static char ISO72Uni(char c){
    if ( (c>=0xb0) && (c<0x100) ){
      c=ISO72U[((int)c)-0xb0];
      }
    return c;  
  }

  public static char ISO72UniNS(char c){
    if ( (c>=0xb0) && (c<0x100) ){
      c=ISO72UNS[((int)c)-0xb0];
      }
    return c;  
  }

  public static char Uni2UniNS(char c){
    if ( (c>=0x370) && (c<0x3d0) ){
      c=Uni2UniNS[((int)c)-0x370];
      }
    return c;  
  }
  
  public static char Uni2ISO7(char c){
    if ( (c>=0x380) && (c<0x3d0) ){
      c=U2ISO7[((int)c)-0x380];
      }
    return c;  
  }



  
 // public string conversion methods
  
  public static String Dos2WinString(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  DosGk2WinGk(s.charAt(i));
    }
    return str;
  }  


  public static String Win2DosString(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  WinGk2DosGk(s.charAt(i));
    }
    return str;
  }  

  public static String Win2UniString(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  WinGk2Uni(s.charAt(i));
    }
    return str;
  }  
  public static String Uni2WinString(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  Uni2WinGk(s.charAt(i));
    }
    return str;
  }  

  public static String ISO72UniString(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  ISO72Uni(s.charAt(i));
    }
    return str;
  }  

  public static String ISO72UniNSString(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  ISO72UniNS(s.charAt(i));
    }
    return str;
  }  

  public static String Uni2UniNSString(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  Uni2UniNS(s.charAt(i));
    }
    return str;
  }  
  
  public static String Uni2ISO7String(String s) {
    String str="";
    for (int i=0;i<s.length();i++){
      str +=  Uni2ISO7(s.charAt(i));
    }
    return str;
  }  

  /*public static void main(String[] arg){
    for ( int i=128;i<=255;i++) {
    if (((i-128)%13)==0) System.out.println();
    System.out.print  (" " +      WinGk2DosGk((char)   i) );
    System.out.print  (" " + (int)WinGk2DosGk((char)   i) );
    }
    
    System.out.println();
    System.out.println();
    
    for ( int i=128;i<=255;i++) {
    if (((i-128)%13)==0) System.out.println();
    System.out.print(" " +      DosGk2WinGk((char)   i) );
    System.out.print(" " + (int)DosGk2WinGk((char)   i) );
    }
    
    System.out.println();
    String s=arg[0];
    for (int i=0;i<s.length();i++){
      System.out.println(((int) s.charAt(i)) + " --> " + ((int) WinGk2DosGk(  s.charAt(i) )) );
    }
  
    System.out.println();
    String f = Uni2UniNSString( "\u0392\u0393\u0394\u0360\u03bc\u03cc\u03ce");
    for (int i = 0 ; i < f.length() ; i++) {
      System.out.println(i+" "+Integer.toHexString((int)(f.charAt(i))));
    }
  
  }*/

}

