/*
 * COPYRIGHT (c) 2009 by Institute of Computer Science,
 * Foundation for Research and Technology - Hellas
 * Contact:
 *      POBox 1385, Heraklio Crete, GR-700 13 GREECE
 *      Tel:+30-2810-391632
 *      Fax: +30-2810-391638
 *      E-mail: isl@ics.forth.gr
 *      http://www.ics.forth.gr/isl/cci.html
 *
 *  Original Author  :  K.V. Chandrinos
 *  Modified by: X. Zamboulis, A. Kladogenis, C. Georgis
 *
 *  This file is part of  ISL - Time-Primitive Java-API
 *
 *  ISL - Time-Primitive Java-API is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  ISL - Time-Primitive Java-API is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with ISL - Time-Primitive Java-API.  If not, see <http://www.gnu.org/licenses/>.
 */


/* Windows specific hacks added by K.V. Chandrinos with the
 help of Alexis Paramythis*/
#include "alpar.h"

#include <jni.h>
#include "sistime_Time.h"
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#ifdef SIS_WIN32
        #include <conio.h>
#endif

/* ---------------------------------------------------------------------------------------
         Utility functions that convert java-objects to C-objects and vice-versa
  ---------------------------------------------------------------------------------------- */

// set the integer value of IntegerObject
void integerC2J(JNIEnv *env, int newVal, jobject integer)
{
	jclass cls = env->GetObjectClass(integer);
	jmethodID setID = env->GetMethodID(cls, "setValue", "(I)V");
	env->CallVoidMethod(integer, setID, newVal);
}

// constructs a new jstring from a c-string
void stringC2J(JNIEnv *env, char *cstr, jstring &jstr, int maxlen)
{
	unsigned short *tmp = new unsigned short[maxlen];
	int len = strlen(cstr);
	for (int i=0; i<len && i<maxlen; i++) {
		tmp[i] = ((unsigned short) cstr[i]) & 0xFF;
	}
   jstr = env->NewString(tmp, len);
   delete tmp;
}

// copies a jstring to an allocated c-string
void stringJ2C(JNIEnv *env, jstring jstr, char *cstr, int maxlen)
{
	/* ????? */
	// BIG QUESTION SHOULD WE USE OR NOT THE UFT FUNCTIONS ???
   // and alternative implementations (that unfortunately
   // DOES NOT WORK with greek-characters) follows:
	/*
	const char *tmp_str = env->GetStringUTFChars(jstr, 0);
   int len = env->GetStringUTFLength(jstr);
   int i;
   for (i=0; i<len && i<maxlen; i++)
		cstr[i] = (unsigned char) tmp_str[i];
   cstr[i] = 0;
   env->ReleaseStringUTFChars(jstr, tmp_str);
   */
	const unsigned short *tmp_str = env->GetStringChars(jstr, 0);
	int len = env->GetStringLength(jstr);
   int i;
   for (i=0; i<len && i<maxlen; i++)
		cstr[i] = (unsigned char) tmp_str[i];
   cstr[i] = 0;
	env->ReleaseStringChars(jstr, tmp_str);
}

// converts a StringObject to an allocated c-string
void  stringObjectJ2C(JNIEnv *env, jobject jobj, char* cstr, int maxlen)
{
	jclass cls = env->GetObjectClass(jobj);
	jmethodID getID = env->GetMethodID(cls,"getValue", "()Ljava/lang/String;");
   jstring jstr = (jstring) env->CallObjectMethod(jobj, getID);
   stringJ2C(env, jstr, cstr, maxlen);
}

// converts a c-string to a StringObject
void  stringObjectC2J(JNIEnv *env, char* cstr, jobject jobj, int maxlen)
{
	jclass cls = env->GetObjectClass(jobj);
	jmethodID mID = env->GetMethodID(cls,"setValue", "(Ljava/lang/String;)V");
	jstring jstr;
	stringC2J(env, (char*)cstr, jstr, maxlen);
	env->CallVoidMethod(jobj, mID, jstr);
}


